netapp_ontap.models.cifs_netbios API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.cifs_netbios`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class CifsNetbiosSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the CifsNetbios object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `aliases GET POST PATCH`

    The aliases field of the cifs_netbios.

    Example: ["ALIAS_1","ALIAS_2","ALIAS_3"]

  `enabled GET POST PATCH`

    Specifies whether NetBios name service (NBNS) is enabled for the CIFS. If this service is enabled, the CIFS server will start sending the broadcast for name registration.

  `wins_servers GET POST PATCH`

    The wins_servers field of the cifs_netbios.

    Example: ["10.224.65.20","10.224.65.21"]